"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseAtomFeed = void 0;
const htmlparser2_1 = require("htmlparser2");
const utils_1 = require("../utils");
const parseAtomPagination_1 = require("./parseAtomPagination");
/**
 * Parses an Atom feed
 *
 * See https://datatracker.ietf.org/doc/html/rfc4287
 *
 * @param atom The root feed element
 */
function parseAtomFeed(atom) {
    const children = atom.children;
    const version = atom.attribs.xmlns === 'http://www.w3.org/2005/Atom' ? '1.0' : undefined;
    const lang = htmlparser2_1.DomUtils.getAttributeValue(atom, 'xml:lang');
    const subtitle = htmlparser2_1.DomUtils.getElementsByTagName('subtitle', children, false);
    const links = htmlparser2_1.DomUtils.getElementsByTagName('link', children, false);
    const images = htmlparser2_1.DomUtils.getElementsByTagName(e => e === 'icon' || e === 'logo', children, false);
    return {
        container: {
            type: 'atom-feed',
            version: version,
        },
        pagination: (0, parseAtomPagination_1.parseAtomPagination)(links),
        title: (0, utils_1.getTextByTagName)('title', children, false),
        description: parseAtomContent(subtitle),
        copyright: (0, utils_1.getTextByTagName)('rights', children, false),
        updatedAt: (0, utils_1.getDateByTagName)('updated', children, false),
        url: getAtomLinkUrl(links),
        language: lang,
        image: images.map(img => ({ url: htmlparser2_1.DomUtils.textContent(img) })),
        posts: parseAtomPosts(atom),
    };
}
exports.parseAtomFeed = parseAtomFeed;
/**
 * Parses Atom entries
 *
 * @param atom The root feed element
 */
function parseAtomPosts(atom) {
    const entries = htmlparser2_1.DomUtils.getElementsByTagName('entry', atom.children);
    return entries.map(entry => {
        const children = entry.children;
        const links = htmlparser2_1.DomUtils.getElementsByTagName('link', children);
        const authors = htmlparser2_1.DomUtils.getElementsByTagName('author', children);
        const content = htmlparser2_1.DomUtils.getElementsByTagName('content', children);
        const summary = htmlparser2_1.DomUtils.getElementsByTagName('summary', children);
        const source = (0, utils_1.getElementByTagName)('source', children);
        const categories = htmlparser2_1.DomUtils.getElementsByTagName('category', children);
        const updatedDate = (0, utils_1.getDateByTagName)('updated', children);
        return {
            guid: (0, utils_1.getTextByTagName)('id', children),
            title: (0, utils_1.getTextByTagName)('title', children),
            link: getAtomLinkUrl(links),
            authors: parseAtomAuthors(authors),
            publishedAt: (0, utils_1.getDateByTagName)('published', children) || updatedDate,
            updatedAt: updatedDate,
            content: parseAtomContent(content),
            summary: parseAtomContent(summary),
            media: parseAtomMedia(content),
            source: parseAtomSource(source),
            categories: parseAtomCategories(categories),
        };
    });
}
/**
 * Parses Atom categories
 *
 * @param categories The <category> elements
 */
function parseAtomCategories(categories) {
    return categories.map(cat => ({ name: cat.attribs.label || cat.attribs.term })).filter(cat => cat.name);
}
/**
 * Parses Atom person elements
 *
 * @param authors The <author> elements
 */
function parseAtomAuthors(authors) {
    return authors.map(author => ({
        name: (0, utils_1.getTextByTagName)('name', author),
        email: (0, utils_1.getTextByTagName)('email', author),
        uri: (0, utils_1.getTextByTagName)('uri', author),
    }));
}
/**
 * Parses Atom content elements
 *
 * @param contents The <content>, <summary> or <subtitle> elements
 */
function parseAtomContent(contents) {
    const html = contents.find(e => e.attribs.type === 'html');
    const text = contents.find(e => e.attribs.type === 'text' || !e.attribs.type);
    return {
        html: html ? htmlparser2_1.DomUtils.textContent(html) : undefined,
        text: text ? htmlparser2_1.DomUtils.textContent(text) : undefined,
    };
}
/**
 * Parses Atom media elements
 *
 * @param contents The <content> elements
 */
function parseAtomMedia(contents) {
    const media = contents.filter(e => !!e.attribs.src);
    return media.map(e => {
        return {
            url: e.attribs.src,
            type: e.attribs.type,
        };
    });
}
/**
 * Parses Atom source element
 *
 * @param source The <source> element
 */
function parseAtomSource(source) {
    if (!source)
        return undefined;
    const links = htmlparser2_1.DomUtils.getElementsByTagName('link', source);
    return {
        title: (0, utils_1.getTextByTagName)('title', source),
        url: getAtomLinkUrl(links),
    };
}
/**
 * Gets the Atom link URL
 *
 * @param links The <link> elements
 */
function getAtomLinkUrl(links) {
    if (links.length === 0)
        return undefined;
    const link = links.find(link => link.attribs.type === 'text/html') || links[0];
    return link.attribs.href;
}
