"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseRssFeed = void 0;
const htmlparser2_1 = require("htmlparser2");
const utils_1 = require("../utils");
const parseAtomPagination_1 = require("./parseAtomPagination");
const parseRssAuthors_1 = require("./parseRssAuthors");
/**
 * Parses a RSS feed
 *
 * Supported versions: RSS 0.91, 1.0, 2.0 and 2.0.1
 * See https://www.xml.com/pub/a/2002/12/18/dive-into-xml.html
 * See https://www.rssboard.org/rss-specification
 * See https://web.resource.org/rss/1.0/spec
 * See https://www.rssboard.org/rss-0-9-1
 *
 * @param rss The root RSS element
 */
function parseRssFeed(rss) {
    var _a;
    const version = rss.name === 'rdf:RDF' && !rss.attribs.version ? '1.0' : rss.attribs.version;
    const channel = ((_a = (0, utils_1.getElementByTagName)('channel', rss.children)) === null || _a === void 0 ? void 0 : _a.children) || [];
    const images = htmlparser2_1.DomUtils.getElementsByTagName('image', channel, false);
    const atomLinks = htmlparser2_1.DomUtils.getElementsByTagName('atom:link', rss.children, false);
    return {
        container: {
            type: 'rss-feed',
            version: version,
        },
        pagination: (0, parseAtomPagination_1.parseAtomPagination)(atomLinks),
        title: (0, utils_1.getTextByTagName)('title', channel, false),
        url: (0, utils_1.getTextByTagName)('link', channel, false),
        description: {
            html: (0, utils_1.getTextByTagName)('description', channel, false),
        },
        copyright: (0, utils_1.getTextByTagName)('copyright', channel, false) || (0, utils_1.getTextByTagName)('dc:rights', channel, false),
        updatedAt: (0, utils_1.getDateByTagName)('lastBuildDate', channel, false) || (0, utils_1.getDateByTagName)('dc:date', channel, false),
        language: (0, utils_1.getTextByTagName)('language', channel, false),
        image: parseRssImages(images),
        posts: parseRssPosts(rss),
    };
}
exports.parseRssFeed = parseRssFeed;
/**
 * Parses RSS post items
 *
 * @param rss The root RSS tag
 */
function parseRssPosts(rss) {
    const items = htmlparser2_1.DomUtils.getElementsByTagName('item', rss.children);
    return items.map(item => {
        const children = item.children;
        const categories = htmlparser2_1.DomUtils.getElementsByTagName('category', children);
        const enclosures = htmlparser2_1.DomUtils.findAll(e => e.name === 'enclosure' || e.name === 'media:content', children);
        return {
            guid: (0, utils_1.getTextByTagName)('guid', children),
            title: (0, utils_1.getTextByTagName)('title', children),
            link: (0, utils_1.getTextByTagName)('link', children),
            publishedAt: (0, utils_1.getDateByTagName)('pubDate', children) || (0, utils_1.getDateByTagName)('dc:date', children),
            authors: (0, parseRssAuthors_1.parseRssAuthors)((0, utils_1.getTextByTagName)('author', children), (0, utils_1.getTextByTagName)('dc:creator', children)),
            categories: parseRssCategories(categories),
            media: parseRssMedia(enclosures),
            source: parseRssSource((0, utils_1.getElementByTagName)('source', children)),
            summary: {
                html: (0, utils_1.getTextByTagName)('description', children),
            },
            content: {
                html: (0, utils_1.getTextByTagName)('content:encoded', children),
            },
        };
    });
}
/**
 * Parses <image> elements
 *
 * @param images The elements
 */
function parseRssImages(images) {
    const postImages = images.map(image => {
        const resource = htmlparser2_1.DomUtils.getAttributeValue(image, 'rdf:resource');
        if (resource) {
            return { url: resource };
        }
        return {
            url: (0, utils_1.getTextByTagName)('url', image),
            title: (0, utils_1.getTextByTagName)('title', image),
            /*link: getTextByTagName('link', image),*/
            width: (0, utils_1.getNumberByTagName)('width', image),
            height: (0, utils_1.getNumberByTagName)('height', image),
        };
    });
    return postImages.filter(image => !!image.url);
}
/**
 * Parses <category> elements
 *
 * @param categories The elements
 */
function parseRssCategories(categories) {
    return categories.map(cat => ({ name: htmlparser2_1.DomUtils.textContent(cat) }));
}
/**
 * Parses <enclosure> or <media:content> elements
 *
 * @param enclosures The elements
 */
function parseRssMedia(enclosures) {
    const postMedia = enclosures.map(media => {
        const length = media.attribs.fileSize || media.attribs.length;
        return {
            url: media.attribs.url,
            length: length ? +length : undefined,
            type: media.attribs.type,
        };
    });
    return postMedia.filter(media => !!media.url);
}
/**
 * Parses <source> element
 *
 * @param source The element
 */
function parseRssSource(source) {
    if (!source)
        return undefined;
    return {
        url: source.attribs.url,
        title: htmlparser2_1.DomUtils.textContent(source),
    };
}
