"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseRssInJsonFeed = void 0;
const parseRssAuthors_1 = require("./parseRssAuthors");
/**
 * Parses an RSS in JSON feed into the post list object
 *
 * @param json The RSS in JSON feed
 */
function parseRssInJsonFeed(json) {
    const channel = json.rss.channel;
    return {
        container: {
            type: 'rss-in-json-feed',
            version: getTextValue(json.rss.version),
        },
        title: getTextValue(channel.title),
        url: getTextValue(channel.link),
        description: {
            html: getTextValue(channel.description),
        },
        copyright: getTextValue(channel.copyright),
        updatedAt: getDateValue(channel.lastBuildDate),
        language: getTextValue(channel.language),
        image: parseRssInJsonImages(channel.image),
        posts: parseRssInJsonPosts(channel.item),
        pagination: {},
    };
}
exports.parseRssInJsonFeed = parseRssInJsonFeed;
/**
 * Parses the list of posts from an RSS in JSON feed
 *
 * @param items The list of items
 */
function parseRssInJsonPosts(items) {
    return getArrayValue(items).map(item => ({
        guid: getTextValue(item.guid),
        title: getTextValue(item.title),
        link: getTextValue(item.link),
        summary: {
            html: getTextValue(item.description),
        },
        publishedAt: getDateValue(item.pubDate),
        authors: (0, parseRssAuthors_1.parseRssAuthors)(getTextValue(item.author)),
        categories: parseRssInJsonCategories(item.category),
        media: parseRssInJsonMedia(item.enclosure),
        source: parseRssInJsonSource(item.source),
    }));
}
/**
 * Parses the list of images from an RSS in JSON feed
 *
 * @param images The list of images
 */
function parseRssInJsonImages(images) {
    const media = getArrayValue(images).map(image => ({
        url: image === null || image === void 0 ? void 0 : image.url,
        title: image === null || image === void 0 ? void 0 : image.title,
        width: image === null || image === void 0 ? void 0 : image.width,
        height: image === null || image === void 0 ? void 0 : image.height,
    }));
    return media.filter(media => !!media.url);
}
/**
 * Parses the list of categories from an RSS in JSON feed
 *
 * @param categories The list of categories
 */
function parseRssInJsonCategories(categories) {
    return getArrayValue(categories).map(cat => ({
        name: getTextValue(cat),
    }));
}
/**
 * Parses the list of enclosures from an RSS in JSON feed
 *
 * @param enclosures The list of enclosures
 */
function parseRssInJsonMedia(enclosures) {
    return getArrayValue(enclosures).map(enclosure => ({
        url: enclosure.url,
        type: enclosure.type,
        length: enclosure.length,
    }));
}
/**
 * Parses the source from an RSS in JSON feed
 *
 * @param source The source object
 */
function parseRssInJsonSource(source) {
    if (!source)
        return undefined;
    return {
        title: getTextValue(source),
        url: source.url,
    };
}
/**
 * Gets the inner text from an RSS in JSON property
 *
 * @param value The value of the property
 */
function getTextValue(value) {
    if (typeof value === 'string')
        return value;
    if (typeof value === 'object' && value['#value'])
        return value['#value'].toString();
    return value === null || value === void 0 ? void 0 : value.toString();
}
/**
 * Gets a date from an RSS in JSON property
 *
 * @param value The value of the property
 */
function getDateValue(value) {
    const text = getTextValue(value);
    if (!text)
        return undefined;
    return new Date(text);
}
/**
 * Gets the array from an RSS in JSON property
 *
 * @param value The value of the property
 */
function getArrayValue(value) {
    if (!value)
        return [];
    if (!Array.isArray(value))
        return [value];
    return value;
}
