import { Axios } from 'axios';
import { DiscoveredSource, PostList } from './types';
export interface FetchOptions {
    /**
     * The Axios instance for the HTTP requests
     */
    axios?: Axios;
    /**
     * Whether the HTML contents should be converted to plain text
     */
    fillTextContents?: boolean;
    /**
     * Wordpress API specific options
     */
    wordpress?: WordpressOptions;
}
export interface WordpressOptions {
    /**
     * Whether it should include embedded entities, such as the author, taxonomy and featured media
     *
     * Defaults to true
     */
    includeEmbedded?: boolean;
    /**
     * Whether it will fetch the blog info, such as the title, description, url and images.
     *
     * Setting this to true adds an extra HTTP request.
     *
     * Defaults to false
     */
    fetchBlogInfo?: boolean;
    /**
     * The amount of posts to list
     *
     * Defaults to 10
     */
    limit?: number;
    /**
     * The page number
     *
     * @deprecated The `page` property in the {@link DiscoveredSource} for WordPress is the preferable alternative
     */
    page?: number;
    /**
     * Filters by a search string
     */
    search?: string;
    /**
     * Returns only posts from the given author IDs
     */
    authors?: number[];
    /**
     * Returns only posts from the given category IDs
     */
    categories?: number[];
    /**
     * Returns only posts from the given tag IDs
     */
    tags?: number[];
    /**
     * Any other additional query string parameters
     *
     * See https://developer.wordpress.org/rest-api/reference/posts/#arguments
     */
    additionalParams?: Record<string, string>;
}
/**
 * Fetches the post list from a data source
 *
 * This function can be called as frequent as the list may need to be updated.
 * The data source object can be reused throughout multiple calls.
 *
 * @param source The data source
 * @param options The options
 * @throws Error When the source couldn't be fetched or parsed
 */
export declare function getPostList(source: DiscoveredSource, options?: FetchOptions): Promise<PostList>;
/**
 * Fetches the Wordpress post list from the Wordpress REST API base URL
 *
 * @param wpApiBaseUrl The Wordpress REST API Base URL
 * @param options The options
 * @param page The page number, starting in 1
 * @throws Error When the source couldn't be fetched or parsed
 */
export declare function getWordpressPostList(wpApiBaseUrl: string, options?: FetchOptions, page?: number): Promise<PostList>;
/**
 * Fetches the post list from a RSS, Atom or JSON Feed
 *
 * @param feedUrl The feed URL
 * @param type The feed mime type
 * @param options The options
 * @throws Error When the source couldn't be fetched or parsed
 */
export declare function getFeedPostList(feedUrl: string, type?: string, options?: Omit<FetchOptions, 'wordpress'>): Promise<PostList>;
//# sourceMappingURL=getPostList.d.ts.map