"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFeedPostList = exports.getWordpressPostList = exports.getPostList = void 0;
const axios_1 = __importDefault(require("axios"));
const fetchWordpressPostList_1 = require("./wordpress/fetchWordpressPostList");
const fetchFeedPostList_1 = require("./feed/fetchFeedPostList");
const utils_1 = require("./utils");
/**
 * Fetches the post list from a data source
 *
 * This function can be called as frequent as the list may need to be updated.
 * The data source object can be reused throughout multiple calls.
 *
 * @param source The data source
 * @param options The options
 * @throws Error When the source couldn't be fetched or parsed
 */
function getPostList(source, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        if (source.source === 'wordpress-rest-api')
            return getWordpressPostList(source.url, options, source.page);
        if (source.source === 'feed')
            return getFeedPostList(source.url, source.type, options);
        throw new Error('The source type is unknown');
    });
}
exports.getPostList = getPostList;
/**
 * Fetches the Wordpress post list from the Wordpress REST API base URL
 *
 * @param wpApiBaseUrl The Wordpress REST API Base URL
 * @param options The options
 * @param page The page number, starting in 1
 * @throws Error When the source couldn't be fetched or parsed
 */
function getWordpressPostList(wpApiBaseUrl, options = {}, page) {
    var _a, _b, _c;
    return __awaiter(this, void 0, void 0, function* () {
        const httpClient = (_a = options.axios) !== null && _a !== void 0 ? _a : axios_1.default;
        const list = yield (0, fetchWordpressPostList_1.fetchWordpressPostList)(httpClient, wpApiBaseUrl, (_c = page !== null && page !== void 0 ? page : (_b = options.wordpress) === null || _b === void 0 ? void 0 : _b.page) !== null && _c !== void 0 ? _c : 1, options.wordpress);
        return postProcessPostList(list, options);
    });
}
exports.getWordpressPostList = getWordpressPostList;
/**
 * Fetches the post list from a RSS, Atom or JSON Feed
 *
 * @param feedUrl The feed URL
 * @param type The feed mime type
 * @param options The options
 * @throws Error When the source couldn't be fetched or parsed
 */
function getFeedPostList(feedUrl, type, options = {}) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const httpClient = (_a = options.axios) !== null && _a !== void 0 ? _a : axios_1.default;
        const list = yield (0, fetchFeedPostList_1.fetchFeedPostList)(httpClient, feedUrl, type);
        return postProcessPostList(list, options);
    });
}
exports.getFeedPostList = getFeedPostList;
/**
 * Post process a parsed post list
 * @param list The post list
 * @param options The options
 */
function postProcessPostList(list, options) {
    // Converts HTML contents into plain text contents
    if (options.fillTextContents) {
        convertContentToText(list.description);
        list.posts.forEach(post => {
            convertContentToText(post.content);
            convertContentToText(post.summary);
        });
    }
    return list;
}
/**
 * Converts HTML contents into plain text contents
 * @param content The content object
 */
function convertContentToText(content) {
    if (content && !content.text && content.html) {
        content.text = (0, utils_1.convertHtmlToText)(content.html);
    }
}
