"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseWordpressPosts = exports.parseRawWordpressPosts = void 0;
const utils_1 = require("../utils");
const parseWordpressDateTime_1 = require("./parseWordpressDateTime");
const parseWordpressMedia_1 = require("./parseWordpressMedia");
const isNotWordpressError_1 = require("./isNotWordpressError");
function parseRawWordpressPosts(data) {
    const posts = JSON.parse(data);
    return parseWordpressPosts(posts);
}
exports.parseRawWordpressPosts = parseRawWordpressPosts;
/**
 * Parses a Wordpress post array
 *
 * See https://developer.wordpress.org/rest-api/reference/posts/
 *
 * @param posts The post array
 */
function parseWordpressPosts(posts) {
    return posts.map(post => {
        var _a, _b, _c, _d;
        return {
            guid: (0, utils_1.convertHtmlToText)(post.guid.rendered),
            title: (0, utils_1.convertHtmlToText)((_a = post.title) === null || _a === void 0 ? void 0 : _a.rendered),
            link: post.link,
            content: {
                html: (_b = post.content) === null || _b === void 0 ? void 0 : _b.rendered,
            },
            summary: {
                html: (_c = post.excerpt) === null || _c === void 0 ? void 0 : _c.rendered,
            },
            authors: parseWordpressAuthors(post),
            categories: parseWordpressTerms(post, post.categories, 'category'),
            tags: parseWordpressTerms(post, post.tags, 'post_tag'),
            media: (0, parseWordpressMedia_1.parseWordpressMedia)((_d = post._embedded) === null || _d === void 0 ? void 0 : _d['wp:featuredmedia']),
            publishedAt: (0, parseWordpressDateTime_1.parseWordpressDateTime)(post.date_gmt || post.date),
        };
    });
}
exports.parseWordpressPosts = parseWordpressPosts;
/**
 * Parses Wordpress taxonomy
 *
 * See https://developer.wordpress.org/rest-api/reference/taxonomies/
 *
 * @param post The post object
 * @param ids The taxonomy IDs
 * @param taxonomy The taxonomy type
 */
function parseWordpressTerms(post, ids, taxonomy) {
    if (!ids)
        return [];
    const terms = post._embedded ? post._embedded['wp:term'] : undefined;
    const findTerm = (id) => {
        if (!terms)
            return undefined;
        for (const termList of terms) {
            const term = termList.find(term => term.id === id && term.taxonomy === taxonomy);
            if (term)
                return term;
        }
        return undefined;
    };
    return ids.map(id => {
        const term = findTerm(id);
        return {
            id,
            name: (0, utils_1.convertHtmlToText)(term === null || term === void 0 ? void 0 : term.name),
            url: term === null || term === void 0 ? void 0 : term.link,
        };
    });
}
/**
 * Parses a Wordpress author
 *
 * See https://developer.wordpress.org/rest-api/reference/users/
 *
 * @param post The post object
 */
function parseWordpressAuthors(post) {
    var _a, _b;
    const wordpressAuthors = (_b = (_a = post._embedded) === null || _a === void 0 ? void 0 : _a.author) === null || _b === void 0 ? void 0 : _b.filter(isNotWordpressError_1.isNotWordpressError);
    if (!wordpressAuthors || wordpressAuthors.length === 0)
        return [{ id: post.author }];
    return wordpressAuthors.map(author => ({
        id: author.id,
        name: author.name,
        uri: author.link,
        images: Object.keys(author.avatar_urls).map(size => ({
            url: author.avatar_urls[size],
            height: +size,
            width: +size,
        })),
    }));
}
